@@ -1,6 +1,10 @@
-use std::{any::TypeId, sync::{RwLockReadGuard, RwLockWriteGuard}};
+use std::any::TypeId;
 use crate::{component::{Component, ComponentStorage}, entity::EntityId, group::{Group, partial_owning}, query::{QueryIterator, Queryable}, sparse_set::SparseSet, world::World};
 use super::PartialOwning;
+#[cfg(not(features = "deadlocks"))]
+use std::sync::{RwLockReadGuard, RwLockWriteGuard};
+#[cfg(features = "deadlocks")]
+use no_deadlocks::{RwLockReadGuard, RwLockWriteGuard};
 
 pub struct IterRefRef<'a,A,B> {
     index: usize,
